<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>AbortedByUserError</name>
    <message>
        <location filename="src/errors.py" line="43"/>
        <source>The user aborted the current action.</source>
        <translation>Acción actual abortada por el usuario.</translation>
    </message>
</context>
<context>
    <name>ContentError</name>
    <message>
        <location filename="src/errors.py" line="55"/>
        <source>Could not open file because its contents are invalid, or written in a way not supported by OpenTeacher.</source>
        <translation>No se pudo abrir el archivo porque sus contenidos son inválidos o están escritos de una forma no soportada por OpenTeacher.</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="ui/about.ui" line="14"/>
        <source>About OpenTeacher</source>
        <translation>Acerca de OpenTeacher</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="28"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="106"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="169"/>
        <source>Full license text</source>
        <translation>Texto completo de la licencia</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="195"/>
        <source>Authors</source>
        <translation>Autores</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="208"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="ui/wrtsLogin.ui" line="13"/>
        <source>WRTS - login please:</source>
        <translation>WRTS - por favor ingresa a tu cuenta:</translation>
    </message>
    <message>
        <location filename="ui/wrtsLogin.ui" line="22"/>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="199"/>
        <source>Password:</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="14"/>
        <source>OpenTeacher - Settings</source>
        <translation>OpenTeacher - Preferencias</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="24"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="32"/>
        <source>Language:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="44"/>
        <source>Show &apos;overwrite&apos;-dialogs</source>
        <translation>Mostrar diálogos &quot;Sobreescribir&quot;</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="57"/>
        <source>Show &apos;do you want to save&apos;-dialogs</source>
        <translation>Mostrar diálogos &quot;¿Desea guardar?&quot;</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="70"/>
        <source>Lesson</source>
        <translation>Lección</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="76"/>
        <source>Show &apos;stop lesson&apos;-dialogs</source>
        <translation>Mostrar diálogos &quot;Detener lección&quot;</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="86"/>
        <source>Show &apos;lesson completed&apos;-dialogs</source>
        <translation>Mostrar diálogos &quot;Lección completada&quot;</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="98"/>
        <source>Fade duration when wrong:</source>
        <translation>Si la respuesta es incorrecta, esperar:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="155"/>
        <source>milliseconds</source>
        <translation>milisegundos</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="133"/>
        <source>Repeat mode hint duration:</source>
        <translation>En modo de repetición, mostrar la palabra por:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="168"/>
        <source>Note notation:</source>
        <translation>Formato de nota:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="183"/>
        <source>WRTS</source>
        <translation>WRTS</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="189"/>
        <source>Username:</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="213"/>
        <source>Try to connect to WRTS</source>
        <translation>Tratar de conectar a WRTS</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="216"/>
        <source>Thanks to all Launchpad contributors!</source>
        <translation>¡Agradecemos a todos quienes contribuyen en Launchpad!</translation>
    </message>
    <message>
        <location filename="ui/wrtsListChoice.ui" line="14"/>
        <source>Choose WRTS list:</source>
        <translation>Escoge una lista WRTS:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="230"/>
        <source>Special Characters</source>
        <translation>Caracteres especiales</translation>
    </message>
</context>
<context>
    <name>DocumentationDialog</name>
    <message>
        <location filename="src/openteacher.py" line="356"/>
        <source>Documentation</source>
        <translation>Documentación</translation>
    </message>
</context>
<context>
    <name>InputEmptyError</name>
    <message>
        <location filename="src/errors.py" line="59"/>
        <source>There seems to be no content in the input area</source>
        <translation>El área de contenidos parece estar vacía</translation>
    </message>
</context>
<context>
    <name>InputFormatError</name>
    <message>
        <location filename="src/errors.py" line="63"/>
        <source>There seems to be something wrong with the default input formatting (question = answer)</source>
        <translation>Algo parece andar mal con el formato de ingreso predeterminado (pregunta = respuesta)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="ui/openteacher.ui" line="14"/>
        <source>OpenTeacher</source>
        <translation>OpenTeacher</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="38"/>
        <source>Enter list</source>
        <translation>Ingresa una lista</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="68"/>
        <source>Title:</source>
        <translation>Título:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="81"/>
        <source>Question Language:</source>
        <translation>Idioma de las preguntas:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="94"/>
        <source>Answer Language:</source>
        <translation>Idioma de las respuestas:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="874"/>
        <source>Symbols</source>
        <translation>Símbolos</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="915"/>
        <source>Greek</source>
        <translation>Griego</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="269"/>
        <source>Click here to enter the words in the textfield into the wordlisttable.</source>
        <translation>Haz clic aquí para ingresar las palabras del campo de texto a la lista.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="272"/>
        <source>Enter!</source>
        <translation>¡Ingresar!</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="275"/>
        <source>Ctrl+Return</source>
        <translation>Ctrl+Return</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="297"/>
        <source>Remove selected row(s)</source>
        <translation>Eliminar las columnas seleccionadas</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="300"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="330"/>
        <source>Teach me!</source>
        <translation>¡Enséñame!</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="357"/>
        <source>Question Order:</source>
        <translation>Orden de las preguntas:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="365"/>
        <source>Known-Foreign</source>
        <translation>Conocido-Extranjero</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="370"/>
        <source>Foreign-Known</source>
        <translation>Extranjero-Conocido</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="378"/>
        <source>Lesson Type:</source>
        <translation>Tipo de lección:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="386"/>
        <source>Ask smart (ideal for practising)</source>
        <translation>Inteligente (ideal para practicar)</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="396"/>
        <source>Ask until all answered right</source>
        <translation>Preguntar hasta responder todo bien</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="401"/>
        <source>Ask all once</source>
        <translation>Preguntar todo una vez</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="409"/>
        <source>Lesson Order:</source>
        <translation>Orden de la lección:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="417"/>
        <source>Random</source>
        <translation>Al azar</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="422"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="427"/>
        <source>Reverse</source>
        <translation>Inverso</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="432"/>
        <source>Sorted (ascending)</source>
        <translation>Ascendente</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="437"/>
        <source>Sorted (descending)</source>
        <translation>Descendente</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="445"/>
        <source>Ask Words:</source>
        <translation>Preguntar palabras:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="453"/>
        <source>All</source>
        <translation>Todas</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="458"/>
        <source>Words you never answered correctly</source>
        <translation>Las que nunca has respondido correctamente</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="463"/>
        <source>Hard Words (&gt;50% errors)</source>
        <translation>Las difíciles (más de 50% de errores)</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="508"/>
        <source>Word:</source>
        <translation>Palabra:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="564"/>
        <source>Type Answer</source>
        <translation>Escribir la respuesta</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="815"/>
        <source>Translation:</source>
        <translation>Traducción:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="785"/>
        <source>Click here to check if your answer is right.</source>
        <translation>Haz clic aquí para saber si tu respuesta es correcta.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="788"/>
        <source>Check!</source>
        <translation>¡Revisar!</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="791"/>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="798"/>
        <source>Click here to correct the last checked answer anyway.</source>
        <translation>Haz clic aquí para corregir la última respuesta revisada.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="801"/>
        <source>Correct anyway</source>
        <translation>Corregir de todas formas</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="644"/>
        <source>Click here to view the answer of the current showed question.</source>
        <translation>Haz clic aquí para ver la respuesta a la última pregunta mostrada.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="647"/>
        <source>View answer</source>
        <translation>Ver respuesta</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="660"/>
        <source>Click here if the answer matches to what you were thinking.</source>
        <translation>Haz clic aquí si la respuesta coincide con lo que estabas pensando.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="663"/>
        <source>I was right</source>
        <translation>Yo tenía razón</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="670"/>
        <source>Click here if the answer doesn&apos;t match with what you were thinking.</source>
        <translation>Haz clic aquí si la respuesta no coincide con lo que estabas pensando.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="673"/>
        <source>I was wrong</source>
        <translation>Yo estaba equivocado</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="681"/>
        <source>Shuffle answer</source>
        <translation>Letras desordenadas</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="766"/>
        <source>Hint:</source>
        <translation>Palabra:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="755"/>
        <source>Repeat answer</source>
        <translation>Repetir la palabra</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="808"/>
        <source>Start!</source>
        <translation>¡Comenzar!</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1022"/>
        <source>Total Questions:</source>
        <translation>Total de preguntas:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1057"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1036"/>
        <source>Right Answers:</source>
        <translation>Respuestas correctas:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1050"/>
        <source>Note:</source>
        <translation>Nota:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1093"/>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1097"/>
        <source>&amp;Export</source>
        <translation>&amp;Exportar</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1107"/>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1130"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1137"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1148"/>
        <source>toolBar</source>
        <translation>Barra de herramientas</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1175"/>
        <source>&amp;Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1178"/>
        <source>Open an existing file.</source>
        <translation>Abrir archivo existente.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1181"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1190"/>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1193"/>
        <source>Save the current opened file.</source>
        <translation>Guardar el archivo que se encuentra abierto.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1196"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1205"/>
        <source>&amp;Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1208"/>
        <source>Close OpenTeacher.</source>
        <translation>Cerrar OpenTeacher</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1211"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1220"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1223"/>
        <source>View information about OpenTeacher.</source>
        <translation>Ver información sobre OpenTeacher</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1232"/>
        <source>Save &amp;As</source>
        <translation>Guardar como</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1235"/>
        <source>Save the current opened file under a different name.</source>
        <translation>Guardar con otro nombre el archivo que se encuentra abierto</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1238"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Mayús+S</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1247"/>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1250"/>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1253"/>
        <source>Open a new, empty file.</source>
        <translation>Abrir nuevo archivo vacío.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1256"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1277"/>
        <source>WRTS (online)</source>
        <translation>WRTS (online)</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1268"/>
        <source>Import a wordlist from your online WRTS-account.</source>
        <translation>Importar una lista desde su cuenta WRTS online.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1280"/>
        <source>Export the current opened wordlist to your online WRTS-account.</source>
        <translation>Exportar la lista actual a su cuenta WRTS online.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1292"/>
        <source>Print the current opened file.</source>
        <translation>Imprimir el archivo actual.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1295"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1304"/>
        <source>Settings</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="956"/>
        <source>Cyrillic</source>
        <translation>Cirílico</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1289"/>
        <source>&amp;Print</source>
        <translation>&amp;Imprimir</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1313"/>
        <source>&amp;Documentation</source>
        <translation>&amp;Documentación</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="391"/>
        <source>Interval training</source>
        <translation>Intervalo de formación.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1316"/>
        <source>Documentation</source>
        <translation>Documentación</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="844"/>
        <source>Change lesson settings</source>
        <translation>Cambiar opciones de la lección.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="484"/>
        <source>Back to the lesson</source>
        <translation>Volver a la lección</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="294"/>
        <source>Click here to remove the selected row(s) from the word list table.</source>
        <translation>Haz click aquí para eliminar la(s) fila(s) seleccionada(s) de la tabla de lista de palabras.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="628"/>
        <source>Think answer</source>
        <translation>Piensa una respuesta</translation>
    </message>
</context>
<context>
    <name>NoEqualsSignInInputError</name>
    <message>
        <location filename="src/errors.py" line="79"/>
        <source>One or more lines could not be added (did they contain a = character?)</source>
        <translation>Una o más líneas no se pudieron añadir. (¿Contenían un símbolo = ?)</translation>
    </message>
</context>
<context>
    <name>NoWordsEnteredError</name>
    <message>
        <location filename="src/errors.py" line="91"/>
        <source>You didn&apos;t enter any words! Enter them and try again.</source>
        <translation>¡No has ingresado nada! Ingresa algo y vuelve a intentar.</translation>
    </message>
</context>
<context>
    <name>NoWordsLeftError</name>
    <message>
        <location filename="src/errors.py" line="87"/>
        <source>After filtering the wordlist, no words where left. Adjust the filter.</source>
        <translation>No quedaron palabras después de filtrar la lista. Ajusta el filtro.</translation>
    </message>
</context>
<context>
    <name>NotEnoughMetadataError</name>
    <message>
        <location filename="src/errors.py" line="75"/>
        <source>Please fill in the wordlist title, question language and answer language first. Then try again.</source>
        <translation>Por favor ingresa el título de la lista, el idioma de las preguntas y el de las respuestas, y vuelve a intentar.</translation>
    </message>
</context>
<context>
    <name>OpenError</name>
    <message>
        <location filename="src/errors.py" line="51"/>
        <source>Could not open file. Please check that you have permission to read this file.</source>
        <translation>No se pudo abrir el archivo. Revisa si tienes permiso para leerlo.</translation>
    </message>
</context>
<context>
    <name>OpenTeacher</name>
    <message>
        <location filename="src/openteacher.py" line="220"/>
        <source>Code</source>
        <translation>Código</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="225"/>
        <source>Localisation</source>
        <translation>Localización</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="319"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1250"/>
        <source>No selection was detected.</source>
        <translation>No se detectó una selección.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1530"/>
        <source>Correct answer</source>
        <translation>Respuesta correcta</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1625"/>
        <source>Translation: </source>
        <translation>Traducción:</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1634"/>
        <source>Think about the answer, and press the &apos;View answer&apos; button when you&apos;re done.</source>
        <translation>Piensa en la respuesta y presiona &quot;Ver respuesta&quot; cuando estés listo.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1733"/>
        <source>Hint:</source>
        <translation>Palabra:</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1726"/>
        <source>Click the button to start.</source>
        <translation>Presiona el botón para comenzar.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1788"/>
        <source>Test completed!</source>
        <translation>¡Prueba completada!</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1788"/>
        <source>Test completed! Your note:</source>
        <translation>¡Prueba completada! Tu nota:</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1940"/>
        <source>Message</source>
        <translation>Mensaje</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1940"/>
        <source>Do you want to save changes?</source>
        <translation>¿Deseas guardar los cambios?</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1960"/>
        <source>Exit lesson</source>
        <translation>Salir de la lección</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1960"/>
        <source>Are you sure you want to stop the lesson?</source>
        <translation>¿Seguro que quieres detener la lección?</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2004"/>
        <source>Supported</source>
        <translation>Soportado</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2083"/>
        <source>Plain text</source>
        <translation>Texto plano</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2098"/>
        <source>Save...</source>
        <translation>Guardar...</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2240"/>
        <source>Print Document</source>
        <translation>Imprimir documento</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2292"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="267"/>
        <source>OpenTeacher authors</source>
        <translation>los autores de OpenTeacher</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1211"/>
        <source>The word(s) were entered successfully.</source>
        <translation>Las palabras fueron ingresadas.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1247"/>
        <source>The word(s) were removed successfully.</source>
        <translation>Las palabras fueron eliminadas.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1888"/>
        <source>The wordlist from WRTS was imported successfully.</source>
        <translation>Se ha importado la lista desde WRTS.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1918"/>
        <source>Export successful</source>
        <translation>Exportación correcta.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1919"/>
        <source>Word list exported to WRTS.</source>
        <translation>Se ha exportado la lista a WRTS.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1994"/>
        <source>New file created.</source>
        <translation>Se ha creado un nuevo archivo.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2022"/>
        <source>The selected file was opened successfully.</source>
        <translation>Se ha abierto el archivo seleccionado.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2165"/>
        <source>File saved.</source>
        <translation>Se ha guardado el archivo.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2246"/>
        <source>The file was printed successfully.</source>
        <translation>Se ha impreso el archivo.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="267"/>
        <source>Project website</source>
        <translation>Sitio web del proyecto</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="264"/>
        <source>OpenTeacher helps you learn a foreign language vocabulary.</source>
        <translation>OpenTeacher te ayuda a aprender vocabulario de idiomas extranjeros.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="996"/>
        <source>een = one</source>
        <translation>uno = one</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="996"/>
        <source>twee = two</source>
        <translation>dos = two</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="996"/>
        <source>drie = three</source>
        <translation>tres = three</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="384"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="384"/>
        <source>This credentials are saved in plain text on your harddrive.</source>
        <translation>Estas credenciales se guardan en tu disco duro en la forma de un archivo de texto.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="384"/>
        <source>Don&apos;t use this function on a public computer!</source>
        <translation>¡No uses esta función en un computador público!</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2004"/>
        <source>Open...</source>
        <translation>Abrir...</translation>
    </message>
</context>
<context>
    <name>OpenTeacherError</name>
    <message>
        <location filename="src/errors.py" line="35"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>QDialogButtonBox</name>
    <message>
        <location filename="src/openteacher.py" line="201"/>
        <source>Close without Saving</source>
        <translation>Cerrar sin guardar</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="188"/>
        <source>&amp;OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="190"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="196"/>
        <source>&amp;Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="192"/>
        <source>&amp;Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="193"/>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="187"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="189"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="195"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="197"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="198"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="199"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="202"/>
        <source>Don&apos;t save</source>
        <translation>No guardar</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="203"/>
        <source>Discard</source>
        <translation>Desechar</translation>
    </message>
</context>
<context>
    <name>QShortcut</name>
    <message>
        <location filename="src/openteacher.py" line="206"/>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="207"/>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="208"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="209"/>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
</context>
<context>
    <name>SaveError</name>
    <message>
        <location filename="src/errors.py" line="71"/>
        <source>Could not save file. Please check that the filename is correct and that you have permission to write to the save location.</source>
        <translation>No se pudo guardar el archivo. Revise el nombre del archivo y asegúrese de tener los permisos necesarios para escribir en el directorio donde desea guardarlo.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="src/openteacher.py" line="526"/>
        <source>Restart please</source>
        <translation>Por favor, reiniciar</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="497"/>
        <source>Connection to WRTS failed</source>
        <translation>La conexión a WRTS falló.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="500"/>
        <source>Connection to WRTS succeeded</source>
        <translation>Se ha establecido la conexión a WRTS.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="526"/>
        <source>You changed the language. In order to use the newly selected language, you need to restart OpenTeacher.</source>
        <translation>Has cambiado el idioma. Para usar el nuevo idioma tienes que reiniciar OpenTeacher.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="src/openteacher.py" line="411"/>
        <source>Make your choice</source>
        <translation>Selecciona:</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="412"/>
        <source>System default</source>
        <translation>Opciones predeterminadas</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="460"/>
        <source>Make your choice (all examples are good to bad)</source>
        <translation>Selecciona. (Todos estos puntajes van de máximo a mínimo)</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="461"/>
        <source>Percents</source>
        <translation>Porcentaje</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="462"/>
        <source>Dutch</source>
        <translation>Holandés</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="463"/>
        <source>American</source>
        <translation>Estadounidense</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="464"/>
        <source>German</source>
        <translation>Alemán</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="465"/>
        <source>French</source>
        <translation>Francés</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="466"/>
        <source>ECTS</source>
        <translation>ECTS</translation>
    </message>
</context>
<context>
    <name>UnsupportedFileExportError</name>
    <message>
        <location filename="src/errors.py" line="67"/>
        <source>Could not save file. Please specify a valid file extension.</source>
        <translation>No se pudo guardar el archivo. Especifica una extensión de archivo válida.</translation>
    </message>
</context>
<context>
    <name>UnsupportedFileImportError</name>
    <message>
        <location filename="src/errors.py" line="47"/>
        <source>File couldn&apos;t be opened. Unsupported extension.</source>
        <translation>No se pudo abrir el archivo. Extensión no soportada.</translation>
    </message>
</context>
<context>
    <name>WordListTableModel</name>
    <message>
        <location filename="src/openteacher.py" line="661"/>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="662"/>
        <source>Answer</source>
        <translation>Respuesta</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="663"/>
        <source>Second Answer (optional)</source>
        <translation>Segunda respuesta (opcional)</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="664"/>
        <source>Errors</source>
        <translation>Errores</translation>
    </message>
</context>
<context>
    <name>WrtsConnectionError</name>
    <message>
        <location filename="src/errors.py" line="83"/>
        <source>WRTS didn&apos;t accept the connection. Are you sure that your internet connection works and WRTS is online?</source>
        <translation>WRTS no aceptó la conexión. ¿Seguro que estás conectado a Internet y que WRTS está en línea?</translation>
    </message>
</context>
<context>
    <name>WrtsLoginError</name>
    <message>
        <location filename="src/errors.py" line="39"/>
        <source>WRTS didn&apos;t accept the login credentials. Are you sure you entered your e-mail and password correctly?</source>
        <translation>WRTS no aceptó las credenciales. ¿Seguro que ingresaste correctamente tu mail y contraseña?</translation>
    </message>
</context>
</TS>
